You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2016/05/22 01:05:22 UTC

svn commit: r1745006 [4/9] - in /openoffice/trunk/main: ./ accessibility/inc/accessibility/standard/ autodoc/inc/ary/idl/ avmedia/source/framework/ basctl/source/basicide/ basctl/source/inc/ basegfx/inc/basegfx/color/ basegfx/inc/basegfx/polygon/ baseg...

Modified: openoffice/trunk/main/framework/source/uielement/newmenucontroller.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/uielement/newmenucontroller.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/uielement/newmenucontroller.cxx (original)
+++ openoffice/trunk/main/framework/source/uielement/newmenucontroller.cxx Sun May 22 01:05:14 2016
@@ -457,7 +457,7 @@ void SAL_CALL NewMenuController::itemSel
 
     if ( xDispatch.is() )
     {
-        // Call dispatch asychronously as we can be destroyed while dispatch is
+        // Call dispatch asynchronously as we can be destroyed while dispatch is
         // executed. VCL is not able to survive this as it wants to call listeners
         // after select!!!
         NewDocument* pNewDocument = new NewDocument;

Modified: openoffice/trunk/main/framework/source/uielement/recentfilesmenucontroller.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/uielement/recentfilesmenucontroller.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/uielement/recentfilesmenucontroller.cxx (original)
+++ openoffice/trunk/main/framework/source/uielement/recentfilesmenucontroller.cxx Sun May 22 01:05:14 2016
@@ -266,7 +266,7 @@ void RecentFilesMenuController::executeE
 
     if ( xDispatch.is() )
     {
-        // Call dispatch asychronously as we can be destroyed while dispatch is
+        // Call dispatch asynchronously as we can be destroyed while dispatch is
         // executed. VCL is not able to survive this as it wants to call listeners
         // after select!!!
         LoadRecentFile* pLoadRecentFile = new LoadRecentFile;

Modified: openoffice/trunk/main/framework/source/xml/acceleratorconfigurationreader.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/source/xml/acceleratorconfigurationreader.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/framework/source/xml/acceleratorconfigurationreader.cxx (original)
+++ openoffice/trunk/main/framework/source/xml/acceleratorconfigurationreader.cxx Sun May 22 01:05:14 2016
@@ -51,7 +51,7 @@
 namespace framework{
 
 //-----------------------------------------------
-/* Throws a SaxException in case a wrong formated XML
+/* Throws a SaxException in case a wrong formatted XML
    structure was detected.
    
    This macro combined the given comment with a generic
@@ -127,7 +127,7 @@ void SAL_CALL AcceleratorConfigurationRe
     EXMLElement eElement = AcceleratorConfigurationReader::implst_classifyElement(sElement);
     
     // Note: We handle "accel:item" before "accel:acceleratorlist" to perform this operation.
-    // Because an item occures very often ... a list should occure one times only!
+    // Because an item occurs very often ... a list should occur one times only!
     if (eElement == E_ELEMENT_ITEM)
     {
         if (!m_bInsideAcceleratorList)
@@ -222,7 +222,7 @@ void SAL_CALL AcceleratorConfigurationRe
     EXMLElement eElement = AcceleratorConfigurationReader::implst_classifyElement(sElement);
     
     // Note: We handle "accel:item" before "accel:acceleratorlist" to perform this operation.
-    // Because an item occures very often ... a list should occure one times only!
+    // Because an item occurs very often ... a list should occur one times only!
     if (eElement == E_ELEMENT_ITEM)
     {
         if (!m_bInsideAcceleratorItem)

Modified: openoffice/trunk/main/framework/test/typecfg/xml2xcd.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/test/typecfg/xml2xcd.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/framework/test/typecfg/xml2xcd.cxx (original)
+++ openoffice/trunk/main/framework/test/typecfg/xml2xcd.cxx Sun May 22 01:05:14 2016
@@ -80,7 +80,7 @@ using namespace ::framework ;
                         all values are 0
                     3)  decrease size of xml file
                         - don't write full localized values
-                        - use own formated string for all non localized values
+                        - use own formatted string for all non localized values
                         - separate "Installed" flag for filters
                     4)  set right values for "Order" property of filters
                     5)  support for ContentHandler
@@ -638,7 +638,7 @@ void XCDGenerator::impl_generateTypeTemp
         m_aData.sBufferStandard.appendAscii( "\t\t\t<schema:value cfg:name=\"Data\" cfg:type=\"string\" cfg:writable=\""                                                                                                                               );
         m_aData.sBufferStandard.appendAscii( m_aData.bWriteable==sal_True ? "true\">\n" : "false\">\n"                                                                                                                                                 );
         m_aData.sBufferStandard.appendAscii("\t\t\t\t<schema:documentation>\n"                                                                                                                                                                         );
-        m_aData.sBufferStandard.appendAscii( "\t\t\t\t\t<schema:description>Contains all data of a type as an own formated string.{Preferred, MediaType, ClipboardFormat, URLPattern, Extensions, DocumentIconID}</schema:description>\n"             );
+        m_aData.sBufferStandard.appendAscii( "\t\t\t\t\t<schema:description>Contains all data of a type as an own formatted string.{Preferred, MediaType, ClipboardFormat, URLPattern, Extensions, DocumentIconID}</schema:description>\n"             );
         m_aData.sBufferStandard.appendAscii( "\t\t\t\t</schema:documentation>\n"                                                                                                                                                                       );
         m_aData.sBufferStandard.appendAscii( "\t\t\t\t<default:data>false</default:data>\n"                                                                                                                                                            );
         m_aData.sBufferStandard.appendAscii( "\t\t\t</schema:value>\n"                                                                                                                                                                                 );

Modified: openoffice/trunk/main/helpcontent2/source/text/scalc/guide/multioperation.xhp
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/helpcontent2/source/text/scalc/guide/multioperation.xhp?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/helpcontent2/source/text/scalc/guide/multioperation.xhp (original)
+++ openoffice/trunk/main/helpcontent2/source/text/scalc/guide/multioperation.xhp Sun May 22 01:05:14 2016
@@ -88,7 +88,7 @@
 <paragraph role="listitem" id="par_id3147474" xml-lang="en-US" l10n="U" oldref="53">Choose <emph>Data - Multiple Operations</emph>.</paragraph>
 </listitem>
 <listitem>
-<paragraph role="listitem" id="par_id3154846" xml-lang="en-US" l10n="U" oldref="54">With the cursor in the <emph>Formulas</emph> field, select cells B5 thru C5.</paragraph>
+<paragraph role="listitem" id="par_id3154846" xml-lang="en-US" l10n="U" oldref="54">With the cursor in the <emph>Formulas</emph> field, select cells B5 through C5.</paragraph>
 </listitem>
 <listitem>
 <paragraph role="listitem" id="par_id3153931" xml-lang="en-US" l10n="CHG" oldref="55">Set the cursor in the <emph>Column input cell</emph> field and click cell B4.</paragraph>
@@ -102,7 +102,7 @@
 <item type="productname">%PRODUCTNAME</item> allows you to carry out joint multiple operations for columns and rows in so-called cross-tables. The formula cell has to refer to both the data range arranged in rows and the one arranged in columns. Select the range defined by both data ranges and call the multiple operation dialog. Enter the reference to the formula in the <emph>Formulas</emph> field. The <emph>Row input cell</emph> and the <emph>Column input cell</emph> fields are used to enter the reference to the corresponding cells of the formula.</paragraph>
 <paragraph role="heading" id="hd_id3149949" xml-lang="en-US" level="3" l10n="U" oldref="57">Calculating with Two Variables</paragraph>
 <paragraph role="paragraph" id="par_id3154808" xml-lang="en-US" l10n="U" oldref="58">Consider columns A and B of the sample table above. You now want to vary not just the quantity produced annually, but also the selling price, and you are interested in the profit in each case.</paragraph>
-<paragraph role="paragraph" id="par_id3149731" xml-lang="en-US" l10n="CHG" oldref="59">Expand the table shown above. D2 thru D11 contain the numbers 500, 1000 and so on, up to 5000. In E1 through H1 enter the numbers 8, 10, 15 and 20.</paragraph>
+<paragraph role="paragraph" id="par_id3149731" xml-lang="en-US" l10n="CHG" oldref="59">Expand the table shown above. D2 through D11 contain the numbers 500, 1000 and so on, up to 5000. In E1 through H1 enter the numbers 8, 10, 15 and 20.</paragraph>
 <list type="ordered">
 <listitem>
 <paragraph role="listitem" id="par_id3152810" xml-lang="en-US" l10n="U" oldref="95">Select the range D1:H11.</paragraph>

Modified: openoffice/trunk/main/i18npool/source/breakiterator/data/line.txt
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/i18npool/source/breakiterator/data/line.txt?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/i18npool/source/breakiterator/data/line.txt (original)
+++ openoffice/trunk/main/i18npool/source/breakiterator/data/line.txt Sun May 22 01:05:14 2016
@@ -419,7 +419,7 @@ $CM+;
 $AL_FOLLOW $CM+ / (
           [$BK $CR $LF $NL $ZW {eof}] |
           $SP+ $CM+ $SP |
-          $SP+ $CM* ([^$OP $CM $SP] | [$AL {eof}]));   # if LB 14 will match, need to surpress this break.
+          $SP+ $CM* ([^$OP $CM $SP] | [$AL {eof}]));   # if LB 14 will match, need to suppress this break.
                                                #  LB14 says    OP SP* x .        
                                                #    becomes    OP SP* x AL
                                                #    becomes    OP SP* x CM+ AL_FOLLOW

Modified: openoffice/trunk/main/i18npool/source/inputchecker/inputsequencechecker_hi.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/i18npool/source/inputchecker/inputsequencechecker_hi.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/i18npool/source/inputchecker/inputsequencechecker_hi.cxx (original)
+++ openoffice/trunk/main/i18npool/source/inputchecker/inputsequencechecker_hi.cxx Sun May 22 01:05:14 2016
@@ -49,7 +49,7 @@ InputSequenceChecker_hi::~InputSequenceC
  */
 #define __UP  1  // ChandraBindu & Anuswar
 #define	__NP  2  // Visarg
-#define __IV	3  // Independant Vowels
+#define __IV	3  // Independent Vowels
 #define __CN	4  // Consonants except _CK & _RC 
 #define __CK	5  // Consonants that can be followed by Nukta
 #define __RC	6  // Ra

Modified: openoffice/trunk/main/i18npool/source/isolang/langid.pl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/i18npool/source/isolang/langid.pl?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/i18npool/source/localedata/data/locale.dtd (original)
+++ openoffice/trunk/main/i18npool/source/localedata/data/locale.dtd Sun May 22 01:05:14 2016
@@ -36,7 +36,7 @@
     java -cp <your_path>/XMLValidator.jar org.unicode.cldr.util.XMLValidator your_data.xml
 
 
-    A second possiblity is:
+    A second possibility is:
 
     - temporarily (!) change the DOCTYPE of your file to read (all on one line)
       <!DOCTYPE Locale SYSTEM "http://hg.services.openoffice.org/DEV300/raw-file/tip/i18npool/source/localedata/data/locale.dtd">
@@ -143,7 +143,7 @@
 
 
 <!-- The LC_FORMAT element contains number format codes and may actually appear
-     twice (with the second ocurrence named LC_FORMAT_1). One section is
+     twice (with the second occurrence named LC_FORMAT_1). One section is
      mandatory and MUST contain at least all required format codes
      formatindex="0" to formatindex="47", MUST NOT contain formatindex 48 and
      49, and MAY contain other format codes. See below ATTLIST FormatElement
@@ -258,7 +258,7 @@
         Formatindex="44" uses no hour code but 100th seconds and the
         Time100SecSeparator.
         Formatindex="45" uses both [HH] hour code and 100th seconds to be able
-        to edit such time values without loosing information.
+        to edit such time values without losing information.
 
     Of usage="CURRENCY":
         formatindices 12, 13, 14, 15, 17 with [$xxx-yyy] notation must use the

Modified: openoffice/trunk/main/i18npool/source/localedata/localedata.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/i18npool/source/localedata/localedata.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/i18npool/source/localedata/localedata.cxx (original)
+++ openoffice/trunk/main/i18npool/source/localedata/localedata.cxx Sun May 22 01:05:14 2016
@@ -484,7 +484,7 @@ Sequence< CalendarItem > &LocaleData::ge
                     break;
                 }
             }
-            // Refered locale does not found, return name for en_US locale.
+            // Referred locale does not found, return name for en_US locale.
             if (index == cals.getLength()) {
                 cals = getAllCalendars(
                         Locale(OUString::createFromAscii("en"), OUString::createFromAscii("US"), OUString()));

Modified: openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/ComponentBase.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/ComponentBase.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/ComponentBase.java (original)
+++ openoffice/trunk/main/javaunohelper/com/sun/star/lib/uno/helper/ComponentBase.java Sun May 22 01:05:14 2016
@@ -76,7 +76,7 @@ public class ComponentBase extends WeakB
                 bInDispose= true;
             }
         }
-        // The notification occures in an unsynchronized block in order to avoid
+        // The notification occurs in an unsynchronized block in order to avoid
         // deadlocks if one of the listeners calls back in a different thread on
         // a synchronized method which uses the same object.
         if (bDoDispose)

Modified: openoffice/trunk/main/jurt/com/sun/star/comp/servicemanager/ServiceManager.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/jurt/com/sun/star/comp/servicemanager/ServiceManager.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/jurt/com/sun/star/comp/servicemanager/ServiceManager.java (original)
+++ openoffice/trunk/main/jurt/com/sun/star/comp/servicemanager/ServiceManager.java Sun May 22 01:05:14 2016
@@ -884,7 +884,7 @@ class ServiceManagerFactory implements
 	 * because there is no the <code>ServiceManager</code> has no constructor with
 	 * arguments.
 	 * <p>
-	 * @return		null - allways throws an exception
+	 * @return		null - always throws an exception
 	 * @param		aArguments arguments for new instance.
  	 * @see         com.sun.star.lang.XSingleServiceFactory
 	 */

Modified: openoffice/trunk/main/l10ntools/inc/treeconfig.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/inc/treeconfig.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/inc/treeconfig.hxx (original)
+++ openoffice/trunk/main/l10ntools/inc/treeconfig.hxx Sun May 22 01:05:14 2016
@@ -42,7 +42,7 @@ class Treeconfig
         // read the config file, returns true in case a config file had been found
         bool parseConfig();
         // returns a string vector containing all active  repositories, returns true in case we are deep inside
-        // of a source tree. This could affect the behavour of the tool
+        // of a source tree. This could affect the behaviour of the tool
         bool getActiveRepositories( vector<string>& active_repos);
 };
 

Modified: openoffice/trunk/main/l10ntools/source/filter/utils/Cache.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/filter/utils/Cache.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/filter/utils/Cache.java (original)
+++ openoffice/trunk/main/l10ntools/source/filter/utils/Cache.java Sun May 22 01:05:14 2016
@@ -63,7 +63,7 @@ public class Cache
     public static final int FORMAT_UNSUPPORTED = -1;
 
     /** identify the configuration format of an office 6.0.
-     *  The own formated data string is used. */
+     *  The own formatted data string is used. */
     public static final int FORMAT_60 = 0;
 
     /** identify the configuration format of an office 6.y.
@@ -310,7 +310,7 @@ public class Cache
      *                      - ...
      *
      *  @return [java.lang.String]
-     *          a formated string, which contains al statistic data.
+     *          a formatted string, which contains al statistic data.
      */
     public synchronized java.lang.String getStatistics()
     {
@@ -1680,7 +1680,7 @@ public class Cache
      *          means the format of the generated xml source.
      *
      *  @return [java.lang.String]
-     *          a xml formated string, which contains all properties
+     *          a xml formatted string, which contains all properties
      *          for this container item.
      */
     public synchronized java.lang.String getItemAsXML(int              eItemType ,

Modified: openoffice/trunk/main/l10ntools/source/filter/utils/XMLHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/l10ntools/source/filter/utils/XMLHelper.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/l10ntools/source/filter/utils/XMLHelper.java (original)
+++ openoffice/trunk/main/l10ntools/source/filter/utils/XMLHelper.java Sun May 22 01:05:14 2016
@@ -475,7 +475,7 @@ public class XMLHelper
 
         // step over all list items and add it to a string buffer
         // Every item will be separated by a default separator "\n" first.
-        // Because "\n" is not a valid separator at all and can`t occure inside
+        // Because "\n" is not a valid separator at all and can`t occur inside
         // our list items. During we step over all items, we check if our current separator
         // (we use a list of possible ones!) clash with an item.
         // If it clash - we step to the next possible separator.
@@ -574,7 +574,7 @@ public class XMLHelper
 
         for (int t=0; t<nPrettyTabs; ++t)
             sXML.append("\t");
-        // !Our localized values must be formated at a deeper coloum
+        // !Our localized values must be formatted at a deeper coloum
         // then its property name!
         ++nPrettyTabs;
 

Modified: openoffice/trunk/main/lingucomponent/source/hyphenator/altlinuxhyph/hyphen/hyphenimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/lingucomponent/source/hyphenator/altlinuxhyph/hyphen/hyphenimp.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/lingucomponent/source/hyphenator/altlinuxhyph/hyphen/hyphenimp.cxx (original)
+++ openoffice/trunk/main/lingucomponent/source/hyphenator/altlinuxhyph/hyphen/hyphenimp.cxx Sun May 22 01:05:14 2016
@@ -67,7 +67,7 @@ using namespace com::sun::star::uno;
 using namespace com::sun::star::linguistic2;
 using namespace linguistic;
 
-// values asigned to capitalization types
+// values assigned to capitalization types
 #define CAPTYPE_UNKNOWN 0
 #define CAPTYPE_NOCAP   1
 #define CAPTYPE_INITCAP 2

Modified: openoffice/trunk/main/lingucomponent/source/thesaurus/libnth/nthesimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/lingucomponent/source/thesaurus/libnth/nthesimp.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/lingucomponent/source/thesaurus/libnth/nthesimp.cxx (original)
+++ openoffice/trunk/main/lingucomponent/source/thesaurus/libnth/nthesimp.cxx Sun May 22 01:05:14 2016
@@ -48,7 +48,7 @@
 #include <set>
 #include <string.h>
 
-// values asigned to capitalization types
+// values assigned to capitalization types
 #define CAPTYPE_UNKNOWN 0
 #define CAPTYPE_NOCAP   1
 #define CAPTYPE_INITCAP 2

Modified: openoffice/trunk/main/linguistic/source/lngopt.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/linguistic/source/lngopt.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/linguistic/source/lngopt.cxx (original)
+++ openoffice/trunk/main/linguistic/source/lngopt.cxx Sun May 22 01:05:14 2016
@@ -58,7 +58,7 @@ using namespace com::sun::star::registry
 ///////////////////////////////////////////////////////////////////////////
 
 
-// static member intialization
+// static member initialization
 SvtLinguOptions *	LinguOptions::pData	= NULL;
 vos::ORefCount		LinguOptions::aRefCount;
 

Modified: openoffice/trunk/main/linguistic/source/misc2.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/linguistic/source/misc2.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/linguistic/source/misc2.cxx (original)
+++ openoffice/trunk/main/linguistic/source/misc2.cxx Sun May 22 01:05:14 2016
@@ -182,10 +182,10 @@ static uno::Sequence< rtl::OUString > Ge
     }
     if (bSuccess)
     {
-        // build resulting sequence by adding the pathes in the following order:
+        // build resulting sequence by adding the paths in the following order:
         // 1. writable path
-        // 2. all user pathes
-        // 3. all internal pathes
+        // 2. all user paths
+        // 3. all internal paths
         sal_Int32 nMaxEntries = aInternalPaths.getLength() + aUserPaths.getLength();
         if (aWritablePath.getLength() > 0)
             ++nMaxEntries;

Modified: openoffice/trunk/main/package/source/xstor/ohierarchyholder.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/xstor/ohierarchyholder.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/xstor/ohierarchyholder.cxx (original)
+++ openoffice/trunk/main/package/source/xstor/ohierarchyholder.cxx Sun May 22 01:05:14 2016
@@ -162,7 +162,7 @@ uno::Reference< embed::XExtendedStorageS
 		}
 	}
 
-	// the subelement was opened successfuly, remember the storage to let it be locked
+	// the subelement was opened successfully, remember the storage to let it be locked
 	m_xOwnStorage = xOwnStor;
 
 	return xResult;

Modified: openoffice/trunk/main/package/source/xstor/owriteablestream.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/xstor/owriteablestream.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/xstor/xfactory.cxx (original)
+++ openoffice/trunk/main/package/source/xstor/xfactory.cxx Sun May 22 01:05:14 2016
@@ -132,7 +132,7 @@ uno::Reference< uno::XInterface > SAL_CA
 			OSL_ENSURE( sal_False, "Wrong second argument!\n" );
 			throw lang::IllegalArgumentException(); // TODO:
 		}
-		// it's allways possible to read written storage in this implementation
+		// it's always possible to read written storage in this implementation
 		nStorageMode |= embed::ElementModes::READ;
 	}
 

Modified: openoffice/trunk/main/package/source/xstor/xstorage.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/xstor/xstorage.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/zippackage/ZipPackage.cxx (original)
+++ openoffice/trunk/main/package/source/zippackage/ZipPackage.cxx Sun May 22 01:05:14 2016
@@ -204,7 +204,7 @@ ZipPackage::~ZipPackage( void )
 	// it should disconnect all the children from itself during destruction automatically.
 	// So there is no need in explicit m_pRootFolder->releaseUpwardRef() call here any more
 	// since m_pRootFolder has no parent and cleaning of it's children will be done automatically
-	// during m_pRootFolder dieing by refcount.
+	// during m_pRootFolder dying by refcount.
 }
 
 //--------------------------------------------------------
@@ -408,7 +408,7 @@ void ZipPackage::parseManifest()
 				
             if ( !bManifestParsed )
             {
-                // the manifest.xml could not be successfuly parsed, this is an inconsistent package
+                // the manifest.xml could not be successfully parsed, this is an inconsistent package
                 if ( aPackageMediatype.compareToAscii( RTL_CONSTASCII_STRINGPARAM( "application/vnd." ) ) == 0 )
                 {
                     // accept only types that look similar to own mediatypes
@@ -1109,7 +1109,7 @@ void ZipPackage::WriteContentTypes( ZipO
         ( *aIter )[PKG_MNFST_MEDIATYPE].Value >>= aType;
         if ( aType.getLength() )
         {
-            // only nonempty type makes sence here
+            // only nonempty type makes sense here
             nSeqLength++;
             ( *aIter )[PKG_MNFST_FULLPATH].Value >>= aPath;
             aOverridesSequence[nSeqLength-1].First = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "/" ) ) + aPath;

Modified: openoffice/trunk/main/psprint_config/configuration/ppds/HP__CLJ1.PS
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/psprint_config/configuration/ppds/HP__CLJ1.PS?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/psprint_config/configuration/ppds/HP__CLJ1.PS (original)
+++ openoffice/trunk/main/psprint_config/configuration/ppds/HP__CLJ1.PS Sun May 22 01:05:14 2016
@@ -464,7 +464,7 @@ restore
 *CloseUI: *OutputBin
 
 *% =============================
-*% Resolution and Apperance Control
+*% Resolution and Appearance Control
 *% =============================
 *DefaultResolution: 300dpi
 

Modified: openoffice/trunk/main/psprint_config/configuration/ppds/KD8650P1.PS
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/psprint_config/configuration/ppds/KD8650P1.PS?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/psprint_config/configuration/ppds/KD8650P1.PS (original)
+++ openoffice/trunk/main/psprint_config/configuration/ppds/KD8650P1.PS Sun May 22 01:05:14 2016
@@ -432,7 +432,7 @@ end
 *%
 *% o For CMY, the PPD allows invocation of the XtraLife laminate
 *%   feature on all reflection media of a size that corresponds to an
-*%   availiable size of XtraLife ribbon.  The PPD disallows the invocation
+*%   available size of XtraLife ribbon.  The PPD disallows the invocation
 *%   of XtraLife laminate through PPD constraints.
 *%
 *% o For black ribbon, the user has no control of the XtraLife lamination

Modified: openoffice/trunk/main/psprint_config/configuration/ppds/XRN17000.PS
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/psprint_config/configuration/ppds/XRN17000.PS?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/psprint_config/configuration/ppds/XRN17000.PS (original)
+++ openoffice/trunk/main/psprint_config/configuration/ppds/XRN17000.PS Sun May 22 01:05:14 2016
@@ -1069,7 +1069,7 @@ currentpagedevice /OutputType known
 >>
   currentpagedevice /OutputType get 
   dup null eq  {pop (Unknown)} { get } ifelse
- } { (Unkown)} ifelse = flush      
+ } { (Unknown)} ifelse = flush      
 "
 *End
 *CloseUI: *OutputBin

Modified: openoffice/trunk/main/psprint_config/configuration/ppds/XRN24320.PS
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/psprint_config/configuration/ppds/XRN24320.PS?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/psprint_config/configuration/ppds/XRN24320.PS (original)
+++ openoffice/trunk/main/psprint_config/configuration/ppds/XRN24320.PS Sun May 22 01:05:14 2016
@@ -1551,7 +1551,7 @@ currentpagedevice /OutputType known
 >>
   currentpagedevice /OutputType get 
   dup null eq  {pop (Unknown)} { get } ifelse
- } { (Unkown)} ifelse = flush      
+ } { (Unknown)} ifelse = flush      
 "
 *End
 *CloseUI: *OutputBin

Modified: openoffice/trunk/main/pyuno/inc/pyuno/pyuno.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/pyuno/inc/pyuno/pyuno.hxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/pyuno/inc/pyuno/pyuno.hxx (original)
+++ openoffice/trunk/main/pyuno/inc/pyuno/pyuno.hxx Sun May 22 01:05:14 2016
@@ -132,7 +132,7 @@ public:
     }
 
     /** clears the reference without decreasing the reference count
-        only seldomly needed ! */
+        only seldom needed ! */
     void scratch()
     {
         m = 0;

Modified: openoffice/trunk/main/pyuno/source/module/pyuno_runtime.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/pyuno/source/module/pyuno_runtime.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/pyuno/source/module/pyuno_runtime.cxx (original)
+++ openoffice/trunk/main/pyuno/source/module/pyuno_runtime.cxx Sun May 22 01:05:14 2016
@@ -538,7 +538,7 @@ PyRef Runtime::any2PyObject (const Any &
         if( ! ret.is() )
         {
             OUStringBuffer buf;
-            buf.appendAscii( "Couldn't instantiate python representation of structered UNO type " );
+            buf.appendAscii( "Couldn't instantiate python representation of structured UNO type " );
             buf.append( a.getValueType().getTypeName() );
             throw RuntimeException( buf.makeStringAndClear(), Reference< XInterface > () );
         }

Modified: openoffice/trunk/main/qadevOOo/runner/base/java_complex.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/runner/base/java_complex.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/runner/base/java_complex.java (original)
+++ openoffice/trunk/main/qadevOOo/runner/base/java_complex.java Sun May 22 01:05:14 2016
@@ -46,7 +46,7 @@ public class java_complex implements Tes
      * This function executes the complex tests given as parameter "-o" or "TestJob". It querys for the correspond class
      * and crates the JobDescription.
      * @param param 
-     * @return true of all tests run successfuly, else false
+     * @return true of all tests run successfully, else false
      */
     public boolean executeTest(TestParameters param)
     {
@@ -73,7 +73,7 @@ public class java_complex implements Tes
      * This function run the given DescEntry[] as ComplexTest
      * @param param 
      * @param entries 
-     * @return true of all tests run successfuly, else false
+     * @return true of all tests run successfully, else false
      */
     public boolean executeTest(TestParameters param, DescEntry[] entries)
     {

Modified: openoffice/trunk/main/qadevOOo/runner/convwatch/OfficePrint.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/runner/convwatch/OfficePrint.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/runner/convwatch/OfficePrint.java (original)
+++ openoffice/trunk/main/qadevOOo/runner/convwatch/OfficePrint.java Sun May 22 01:05:14 2016
@@ -238,7 +238,7 @@ public class OfficePrint {
             }
             catch ( com.sun.star.uno.Exception e )
             {
-                // Some exception occures.FAILED
+                // Some exception occured.FAILED
                 GlobalLogWriter.get().println("UNO Exception caught.");
                 GlobalLogWriter.get().println("Message: " + e.getMessage());
                 e.printStackTrace();
@@ -559,7 +559,7 @@ public class OfficePrint {
             }
             catch ( com.sun.star.uno.Exception e )
             {
-                // Some exception occures.FAILED
+                // Some exception occured.FAILED
                 GlobalLogWriter.get().println("UNO Exception caught.");
                 GlobalLogWriter.get().println("Message: " + e.getMessage());
 
@@ -712,7 +712,7 @@ public class OfficePrint {
             }
             catch ( com.sun.star.uno.Exception e )
             {
-                // Some exception occures.FAILED
+                // Some exception occured.FAILED
                 GlobalLogWriter.get().println("UNO Exception caught.");
                 GlobalLogWriter.get().println("Message: " + e.getMessage());
 

Modified: openoffice/trunk/main/qadevOOo/runner/graphical/OpenOfficePostscriptCreator.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/runner/graphical/OpenOfficePostscriptCreator.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/runner/graphical/OpenOfficePostscriptCreator.java (original)
+++ openoffice/trunk/main/qadevOOo/runner/graphical/OpenOfficePostscriptCreator.java Sun May 22 01:05:14 2016
@@ -285,7 +285,7 @@ public class OpenOfficePostscriptCreator
             }
             catch ( com.sun.star.uno.Exception e )
             {
-                // Some exception occures.FAILED
+                // Some exception occured.FAILED
                 GlobalLogWriter.println("UNO Exception caught.");
                 GlobalLogWriter.println("Message: " + e.getMessage());
                 e.printStackTrace();
@@ -527,7 +527,7 @@ public class OpenOfficePostscriptCreator
             }
             catch ( com.sun.star.uno.Exception e )
             {
-                // Some exception occures.FAILED
+                // Some exception occured.FAILED
                 GlobalLogWriter.println("UNO Exception caught.");
                 GlobalLogWriter.println("Message: " + e.getMessage());
 
@@ -685,7 +685,7 @@ public class OpenOfficePostscriptCreator
             }
             catch ( com.sun.star.uno.Exception e )
             {
-                // Some exception occures.FAILED
+                // Some exception occured.FAILED
                 GlobalLogWriter.println("UNO Exception caught.");
                 GlobalLogWriter.println("Message: " + e.getMessage());
 

Modified: openoffice/trunk/main/qadevOOo/runner/helper/ConfigHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/runner/helper/ConfigHelper.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/runner/helper/ConfigHelper.java (original)
+++ openoffice/trunk/main/qadevOOo/runner/helper/ConfigHelper.java Sun May 22 01:05:14 2016
@@ -346,7 +346,7 @@ public class ConfigHelper
     /**
      * Returns a <CODE>XNameContainer</CODE> of the <CODE>Set</CODE>
      * of the <CODE>Configuration</CODE>
-     * @param setName the name of the Set which sould be returned
+     * @param setName the name of the Set which should be returned
      * @throws com.sun.star.uno.Exception on any error
      * @return A XNameContainer of the Set
      */

Modified: openoffice/trunk/main/qadevOOo/runner/helper/URLHelper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/runner/helper/URLHelper.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/runner/helper/URLHelper.java (original)
+++ openoffice/trunk/main/qadevOOo/runner/helper/URLHelper.java Sun May 22 01:05:14 2016
@@ -189,7 +189,7 @@ public class URLHelper
     // ____________________
 
     /**
-     * This convert an URL (formated as a string) to a struct com.sun.star.util.URL.
+     * This convert an URL (formatted as a string) to a struct com.sun.star.util.URL.
      * It use a special service to do that: the URLTransformer.
      * Because some API calls need it and it's not allowed to set "Complete"
      * part of the util struct only. The URL must be parsed.

Modified: openoffice/trunk/main/qadevOOo/runner/lib/MultiMethodTest.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/runner/lib/MultiMethodTest.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/runner/lib/MultiMethodTest.java (original)
+++ openoffice/trunk/main/qadevOOo/runner/lib/MultiMethodTest.java Sun May 22 01:05:14 2016
@@ -41,7 +41,7 @@ import stats.Summarizer;
  * <p>There are some points that should be fulfilled in a subclass to work
  * correctly in the multi-method framework:
  *
- *   1. each subclass schould define a public field named oObj of type tested
+ *   1. each subclass should define a public field named oObj of type tested
  *   by the subclass, e.g. 'public XText oObj;'. That field will be initialized
  *   by the MultiMethodTest code with the instance of the interface to test.
  *   In a case of service testing the field type should be XPropertySet.

Modified: openoffice/trunk/main/qadevOOo/runner/util/FormTools.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/runner/util/FormTools.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/runner/util/FormTools.java (original)
+++ openoffice/trunk/main/qadevOOo/runner/util/FormTools.java Sun May 22 01:05:14 2016
@@ -88,7 +88,7 @@ public class FormTools {
             oCShape.setSize(size);
             oCShape.setPosition(position);
         } catch ( com.sun.star.uno.Exception e ) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             System.out.println( "Couldn't create instance "+ e );
         }
 
@@ -125,7 +125,7 @@ public class FormTools {
 
 
    		} catch ( com.sun.star.uno.Exception e ) {
-			// Some exception occures.FAILED
+			// Some exception occured.FAILED
 			System.out.println( "Couldn't create instance "+ e );
 		}
 
@@ -160,7 +160,7 @@ public class FormTools {
 
 
    		} catch ( com.sun.star.uno.Exception e ) {
-			// Some exception occures.FAILED
+			// Some exception occured.FAILED
 			System.out.println( "Couldn't create instance "+ e );
 		}
 
@@ -180,7 +180,7 @@ public class FormTools {
 	        oControl = (XInterface) oDocMSF.createInstance(
                                         "com.sun.star.form.component."+kind);
    		} catch ( Exception e ) {
-			// Some exception occures.FAILED
+			// Some exception occured.FAILED
 			System.out.println( "Couldn't create instance "+ kind + ": "+ e );
 		}
         return oControl;

Modified: openoffice/trunk/main/qadevOOo/runner/util/PropertyName.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/runner/util/PropertyName.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/runner/util/PropertyName.java (original)
+++ openoffice/trunk/main/qadevOOo/runner/util/PropertyName.java Sun May 22 01:05:14 2016
@@ -159,7 +159,7 @@ public interface PropertyName {
     final public static String UNXMACXI = "unxmacxi";
 
     /**
-     * can be used to dont backup the user layer, faster office start/stop but less secure default is to backup the user layer
+     * can be used to don't backup the user layer, faster office start/stop but less secure default is to backup the user layer
      */
     final public static String DONT_BACKUP_USERLAYER = "DontBackupUserLayer";
 }

Modified: openoffice/trunk/main/qadevOOo/runner/util/SOfficeFactory.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/runner/util/SOfficeFactory.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/runner/util/SOfficeFactory.java (original)
+++ openoffice/trunk/main/qadevOOo/runner/util/SOfficeFactory.java Sun May 22 01:05:14 2016
@@ -443,7 +443,7 @@ public class SOfficeFactory {
             oInterface = (XInterface) oDocMSF.createInstance("com.sun.star.chart." + kind);
             oDiagram = (XDiagram) UnoRuntime.queryInterface(XDiagram.class, oInterface);
         } catch (Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             System.out.println("Couldn't create " + kind + "-Diagram " + e);
         }
         return oDiagram;
@@ -461,7 +461,7 @@ public class SOfficeFactory {
         try {
             oControl = (XInterface) oDocMSF.createInstance("com.sun.star.form.component." + kind);
         } catch (Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             System.out.println("Couldn't create instance " + kind + ": " + e);
         }
         return oControl;
@@ -479,7 +479,7 @@ public class SOfficeFactory {
         try {
             oInstance = (Object) oDocMSF.createInstance(kind);
         } catch (Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             System.out.println("Couldn't create instance " + kind + ": " + e);
         }
         return oInstance;
@@ -509,14 +509,14 @@ public class SOfficeFactory {
 
 
         } catch (Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             System.out.println("Couldn't create instance " + e);
         }
 
         try {
             oCShape.setControl(aControl);
         } catch (Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             System.out.println("Couldn't get Control " + e);
         }
 

Modified: openoffice/trunk/main/qadevOOo/tests/basic/ifc/awt/XTextComponent/awt_XTextComponent.xba
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/basic/ifc/awt/XTextComponent/awt_XTextComponent.xba?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/basic/ifc/awt/XTextComponent/awt_XTextComponent.xba (original)
+++ openoffice/trunk/main/qadevOOo/tests/basic/ifc/awt/XTextComponent/awt_XTextComponent.xba Sun May 22 01:05:14 2016
@@ -72,7 +72,7 @@ On Error Goto ErrHndl
     vInsertSelection.Min = 0
     vInsertSelection.Max = 3
     oObj.insertText(vInsertSelection,"new")
-    Out.Log("result of getText is: '" + oObj.getText() +"'. It sould be 'newSelection'")
+    Out.Log("result of getText is: '" + oObj.getText() +"'. It should be 'newSelection'")
     bOK = bOK AND (oObj.getText() = "newSelection")
     Test.MethodTested("insertText()", bOK)
 
@@ -95,7 +95,7 @@ On Error Goto ErrHndl
     vSelectionSelection.Min = 0
     vSelectionSelection.Max = 3
     oObj.setSelection(vSelectionSelection)
-    Out.Log("result of getSelectedText is: '" + oObj.getSelectedText() +"'. It sould be 'get'")
+    Out.Log("result of getSelectedText is: '" + oObj.getSelectedText() +"'. It should be 'get'")
     bOK = bOK AND (oObj.getSelectedText() = "get")
     Test.MethodTested("getSelectedText()", bOK)
 
@@ -121,7 +121,7 @@ On Error Goto ErrHndl
     oObj.setMaxTextLen(len2set)
     oObj.setText("0123456789ABCDE")
     cGetText = oObj.getText()
-    Out.Log("result of Len(cGetText) is: '" + Len(cGetText) + "'. It sould be >'" + len2set+"' ")
+    Out.Log("result of Len(cGetText) is: '" + Len(cGetText) + "'. It should be >'" + len2set+"' ")
     bOK = bOK AND (Len(cGetText) > len2set)
     Test.MethodTested("setMaxTextLen()", bOK)
 
@@ -133,7 +133,7 @@ On Error Goto ErrHndl
         len2set = 12
     endif
     oObj.setMaxTextLen(len2set)
-    Out.Log("result of getMaxTextLen is: '" + oObj.getMaxTextLen() +"'. It sould be '"+len2set+"'")
+    Out.Log("result of getMaxTextLen is: '" + oObj.getMaxTextLen() +"'. It should be '"+len2set+"'")
     bOK = bOK AND (oObj.getMaxTextLen() = len2set)
     Test.MethodTested("getMaxTextLen()", bOK)
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XDispatchRecorderSupplier.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XDispatchRecorderSupplier.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XDispatchRecorderSupplier.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XDispatchRecorderSupplier.java Sun May 22 01:05:14 2016
@@ -91,7 +91,7 @@ public class _XDispatchRecorderSupplier
             desktop = (XDesktop) UnoRuntime.queryInterface
                 (XDesktop.class, inst);
         } catch ( com.sun.star.uno.Exception e ) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace( log );
             throw new StatusException( "Couldn't create document", e );
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XFrameLoader.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XFrameLoader.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XFrameLoader.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XFrameLoader.java Sun May 22 01:05:14 2016
@@ -113,7 +113,7 @@ public class _XFrameLoader extends Multi
                 shortWait() ;
                 frame = dsk.getCurrentFrame() ;
             } catch ( com.sun.star.uno.Exception e ) {
-                // Some exception occures.FAILED
+                // Some exception occured.FAILED
                 e.printStackTrace( log );
                 throw new StatusException( "Couldn't create a frame.", e );
             }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XSynchronousFrameLoader.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XSynchronousFrameLoader.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XSynchronousFrameLoader.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/frame/_XSynchronousFrameLoader.java Sun May 22 01:05:14 2016
@@ -109,7 +109,7 @@ public class _XSynchronousFrameLoader ex
                     (XURLTransformer.class, o) ;
 
             } catch ( com.sun.star.uno.Exception e ) {
-                // Some exception occures.FAILED
+                // Some exception occured.FAILED
                 e.printStackTrace( log );
                 throw new StatusException( "Couldn't create a document.", e );
             }

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/i18n/_XExtendedIndexEntrySupplier.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/i18n/_XExtendedIndexEntrySupplier.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/i18n/_XExtendedIndexEntrySupplier.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/i18n/_XExtendedIndexEntrySupplier.java Sun May 22 01:05:14 2016
@@ -90,7 +90,7 @@ public class _XExtendedIndexEntrySupplie
             for (int j = 0; j < algorithms.size(); j++) {
                 String[] algs = (String[])algorithms.get(new Integer(j));
                 for (int k=0;k<algs.length;k++) {
-                log.println("\t Algorythm :" + 
+                log.println("\t Algorithm :" + 
                             algs[k]);
                 oObj.loadAlgorithm(locales[i], algs[k], CollatorOptions.CollatorOptions_IGNORE_CASE);
                 log.println("\t\t Get: " + 

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryComposer.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryComposer.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryComposer.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sdb/_XSingleSelectQueryComposer.java Sun May 22 01:05:14 2016
@@ -235,7 +235,7 @@ public class _XSingleSelectQueryComposer
     }
 
     /**
-    * The group which was setted by <code>setGroup</code> must be returned
+    * The group which was set by <code>setGroup</code> must be returned
     * while calling from object relation <code>XQueryAna</code> 
     * method <code>getGroup</code>
     */
@@ -253,7 +253,7 @@ public class _XSingleSelectQueryComposer
     
     
     /**
-    * The cluase which was setted by <code>setHavingClause</code> must be returned
+    * The cluase which was set by <code>setHavingClause</code> must be returned
     * while calling from object relation <code>XQueryAna</code> 
     * method <code>getHavingClause</code>
     */
@@ -373,7 +373,7 @@ public class _XSingleSelectQueryComposer
 
     /**
     * Method <code>getOrder</code> from object relation <code>xQueryAna</code>
-    * checks the order which was setted while calling <code>setOrder</code>
+    * checks the order which was set while calling <code>setOrder</code>
     */
     public void _setOrder() {
         try{

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sdbc/_XRowSet.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sdbc/_XRowSet.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sdbc/_XRowSet.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sdbc/_XRowSet.java Sun May 22 01:05:14 2016
@@ -99,7 +99,7 @@ public class _XRowSet extends MultiMetho
 
     /**
     * Reexecutes the RowSet and checks that listener was called. <p>
-    * Has OK status if no exceptions were rised and listener was called.
+    * Has OK status if no exceptions were raised and listener was called.
     */
     public void _execute() {
         requiredMethod("addRowSetListener()");

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetAuditing.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetAuditing.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetAuditing.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetAuditing.java Sun May 22 01:05:14 2016
@@ -75,7 +75,7 @@ public class _XSheetAuditing extends Mul
         
         // get a sheet for changing the cells
         XSpreadsheet xSheet = (XSpreadsheet)tEnv.getObjRelation("XSheetAuditing.Spreadsheet");
-        if (xSheet == null) // query on ther object
+        if (xSheet == null) // query on their object
             xSheet = (XSpreadsheet)UnoRuntime.queryInterface(XSpreadsheet.class, oObj);
         if (xSheet == null) 
             throw new StatusException(Status.failed("'XSheetAuditing.Spreadsheet' object relation not found."));

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetCellCursor.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetCellCursor.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetCellCursor.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XSheetCellCursor.java Sun May 22 01:05:14 2016
@@ -251,7 +251,7 @@ public class _XSheetCellCursor extends M
         }
 
         mergeRange.merge(true);
-        log.println("DB: Successfuly merged.") ;
+        log.println("DB: Successfully merged.") ;
 
         oObj.collapseToMergedArea() ;
         log.println("DB: Successfully collapseToMergedArea() method called");

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XViewFreezable.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XViewFreezable.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XViewFreezable.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/sheet/_XViewFreezable.java Sun May 22 01:05:14 2016
@@ -52,7 +52,7 @@ public class _XViewFreezable extends Mul
     /**
     * Test calls the method, checks returned value, unfreezes panes, calls the
     * method and checks returned value again. <p>
-    * Has <b> OK </b> status if returned value is true after firts call and
+    * Has <b> OK </b> status if returned value is true after first call and
     * returned value is false after second. <p>
     * The following method tests are to be completed successfully before :
     * <ul>

Modified: openoffice/trunk/main/qadevOOo/tests/java/ifc/task/_XInteractionHandler.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/ifc/task/_XInteractionHandler.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/ifc/task/_XInteractionHandler.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/ifc/task/_XInteractionHandler.java Sun May 22 01:05:14 2016
@@ -75,7 +75,7 @@ public class _XInteractionHandler extend
     }
 
     /**
-    * Sinse this test is interactive (dialog window can't be
+    * Since this test is interactive (dialog window can't be
     * disposed using API) it is skipped. <p>
     * Always has <b>SKIPPED.OK</b> status .
     */

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/ODatasourceBrowser.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/ODatasourceBrowser.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/ODatasourceBrowser.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/ODatasourceBrowser.java Sun May 22 01:05:14 2016
@@ -203,7 +203,7 @@ public class ODatasourceBrowser extends
             log.println("creating a text document");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }
@@ -262,7 +262,7 @@ public class ODatasourceBrowser extends
                                             XInitialization.class, oObj);
             xInit.initialize(params);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't initialize document", e);
         }
@@ -284,7 +284,7 @@ public class ODatasourceBrowser extends
         try {
             xCtrl = xCtrlAccess.getControl(shapeModel);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
         }
 

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/SbaXGridControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/SbaXGridControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/SbaXGridControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_dbaccess/SbaXGridControl.java Sun May 22 01:05:14 2016
@@ -137,7 +137,7 @@ public class SbaXGridControl extends Tes
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }
@@ -273,19 +273,19 @@ public class SbaXGridControl extends Tes
             aControl4.setPropertyValue("DataField", "Title");
             aControl4.setPropertyValue("Label", "Title");
         } catch (com.sun.star.lang.IllegalArgumentException e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             log.println("!!! Couldn't create instance : " + e);
             throw new StatusException("Can't create column instances.", e);
         } catch (com.sun.star.lang.WrappedTargetException e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             log.println("!!! Couldn't create instance : " + e);
             throw new StatusException("Can't create column instances.", e);
         } catch (com.sun.star.beans.PropertyVetoException e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             log.println("!!! Couldn't create instance : " + e);
             throw new StatusException("Can't create column instances.", e);
         } catch (com.sun.star.beans.UnknownPropertyException e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             log.println("!!! Couldn't create instance : " + e);
             throw new StatusException("Can't create column instances.", e);
         }
@@ -469,7 +469,7 @@ public class SbaXGridControl extends Tes
             oCShape.setSize(size);
             oCShape.setPosition(position);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             System.out.println("Couldn't create Grid" + e);
             throw new StatusException("Couldn't create Grid", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/GenericModelTest.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/GenericModelTest.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/GenericModelTest.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/GenericModelTest.java Sun May 22 01:05:14 2016
@@ -213,7 +213,7 @@ public class GenericModelTest extends Te
     
     protected static String m_XPropertyContainer_propertyNotRemovable = "HelpText";
     /**
-     * If this variable is true some more debug info was logged. It was setted by the parameter variable 
+     * If this variable is true some more debug info was logged. It was set by the parameter variable 
      * <code>debug_is_active</code>
      */
     protected static boolean debug = false;

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OButtonControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OButtonControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OButtonControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OButtonControl.java Sun May 22 01:05:14 2016
@@ -96,7 +96,7 @@ public class OButtonControl extends Test
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OCheckBoxControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OCheckBoxControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OCheckBoxControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OCheckBoxControl.java Sun May 22 01:05:14 2016
@@ -104,7 +104,7 @@ public class OCheckBoxControl extends Te
             log.println( "creating a textdocument" );
             xTextDoc = SOF.createTextDoc( null );
         } catch ( com.sun.star.uno.Exception e ) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace( log );
             throw new StatusException( "Couldn't create document", e );
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OComboBoxControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OComboBoxControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OComboBoxControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OComboBoxControl.java Sun May 22 01:05:14 2016
@@ -108,7 +108,7 @@ public class OComboBoxControl extends Te
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OCurrencyControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OCurrencyControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OCurrencyControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OCurrencyControl.java Sun May 22 01:05:14 2016
@@ -108,7 +108,7 @@ public class OCurrencyControl extends Te
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ODateControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ODateControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ODateControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ODateControl.java Sun May 22 01:05:14 2016
@@ -107,7 +107,7 @@ public class ODateControl extends TestCa
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OEditControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OEditControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OEditControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OEditControl.java Sun May 22 01:05:14 2016
@@ -108,7 +108,7 @@ public class OEditControl extends TestCa
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OFileControlModel.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OFileControlModel.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OFileControlModel.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OFileControlModel.java Sun May 22 01:05:14 2016
@@ -179,7 +179,7 @@ public class OFileControlModel extends T
             aShape.setSize(size);
             aShape.setPosition(position);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             log.println("Couldn't create a component " + e);
             throw new StatusException(Status.failed("Can't create component"));
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OFormattedControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OFormattedControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OFormattedControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OFormattedControl.java Sun May 22 01:05:14 2016
@@ -104,7 +104,7 @@ public class OFormattedControl extends T
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OGridControlModel.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OGridControlModel.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OGridControlModel.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OGridControlModel.java Sun May 22 01:05:14 2016
@@ -193,7 +193,7 @@ public class OGridControlModel extends G
             aControl4 = columns.createColumn("TextField");
             aControl5 = columns.createColumn("TextField");
         } catch (com.sun.star.lang.IllegalArgumentException e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             log.println("!!! Couldn't create instance : " + e);
             throw new StatusException("Can't create column instances.", e);
         }
@@ -356,7 +356,7 @@ class OGridControlModelold extends TestC
             aControl4 = columns.createColumn("TextField");
             aControl5 = columns.createColumn("TextField");
         } catch (com.sun.star.lang.IllegalArgumentException e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             log.println("!!! Couldn't create instance : " + e);
             throw new StatusException("Can't create column instances.", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OGroupBoxControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OGroupBoxControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OGroupBoxControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OGroupBoxControl.java Sun May 22 01:05:14 2016
@@ -86,7 +86,7 @@ public class OGroupBoxControl extends Te
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OHiddenModel.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OHiddenModel.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OHiddenModel.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OHiddenModel.java Sun May 22 01:05:14 2016
@@ -103,7 +103,7 @@ public class OHiddenModel extends TestCa
             log.println("creating a draw document");
             xDrawDoc = SOF.createDrawDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OImageButtonControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OImageButtonControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OImageButtonControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OImageButtonControl.java Sun May 22 01:05:14 2016
@@ -91,7 +91,7 @@ public class OImageButtonControl extends
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OImageControlControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OImageControlControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OImageControlControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OImageControlControl.java Sun May 22 01:05:14 2016
@@ -92,7 +92,7 @@ public class OImageControlControl extend
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OListBoxControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OListBoxControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OListBoxControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OListBoxControl.java Sun May 22 01:05:14 2016
@@ -60,7 +60,7 @@ public class OListBoxControl extends Tes
             log.println( "creating a textdocument" );
             xTextDoc = SOF.createTextDoc( null );
         } catch ( com.sun.star.uno.Exception e ) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace( log );
             throw new StatusException( "Couldn't create document", e );
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ONavigationBarControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ONavigationBarControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ONavigationBarControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ONavigationBarControl.java Sun May 22 01:05:14 2016
@@ -61,7 +61,7 @@ public class ONavigationBarControl exten
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ONumericControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ONumericControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ONumericControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/ONumericControl.java Sun May 22 01:05:14 2016
@@ -107,7 +107,7 @@ public class ONumericControl extends Tes
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }

Modified: openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OPatternControl.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OPatternControl.java?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OPatternControl.java (original)
+++ openoffice/trunk/main/qadevOOo/tests/java/mod/_forms/OPatternControl.java Sun May 22 01:05:14 2016
@@ -107,7 +107,7 @@ public class OPatternControl extends Tes
             log.println("creating a textdocument");
             xTextDoc = SOF.createTextDoc(null);
         } catch (com.sun.star.uno.Exception e) {
-            // Some exception occures.FAILED
+            // Some exception occured.FAILED
             e.printStackTrace(log);
             throw new StatusException("Couldn't create document", e);
         }
--- openoffice/trunk/main/i18npool/source/isolang/langid.pl (original)
+++ openoffice/trunk/main/i18npool/source/isolang/langid.pl Sun May 22 01:05:14 2016
@@ -55,7 +55,7 @@ sub Usage()
         "A language-country pair will lookup a xx-YY mapping from isolang.cxx,\n",
         "for example: 'en-US' or 'de-' or '-CH',\n",
         "xx and YY can be given case insensitive, will be lowered-uppered internally,\n",
-        "and xx and YY themselfs may be regular expressions.\n",
+        "and xx and YY themselves may be regular expressions.\n",
         "Also here a list of matches will be processed.\n\n",
 
         "If option --single is given, only the first match will be processed.\n\n";
@@ -260,7 +260,7 @@ sub main()
         }
     }
     # If the string given is of the form xx-yy lookup a language,country pair
     # to obtain the define identifier. xx and yy themselfs may be regexps.
     # xx- is a short form for 'xx-.*' and -yy a short form for '.*-yy'
     if ($grepdef =~ /^(.*)-$/) {
         $grepdef = $1 . "-.*"; }
@@ -260,7 +260,7 @@ sub main()
     }
     # If the string given is of the form xx-yy lookup a language,country pair
-    # to obtain the define identifier. xx and yy themselfs may be regexps.
+    # to obtain the define identifier. xx and yy themselves may be regexps.
     # xx- is a short form for 'xx-.*' and -yy a short form for '.*-yy'
     if ($grepdef =~ /^(.*)-$/) {

Modified: openoffice/trunk/main/i18npool/source/localedata/data/locale.dtd
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/i18npool/source/localedata/data/locale.dtd?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/xstor/owriteablestream.cxx (original)
+++ openoffice/trunk/main/package/source/xstor/owriteablestream.cxx Sun May 22 01:05:14 2016
@@ -312,7 +312,7 @@ OWriteStream_Impl::OWriteStream_Impl( OS
 	OSL_ENSURE( xPackage.is(), "No package component is provided!\n" );
 	OSL_ENSURE( m_xFactory.is(), "No package stream is provided!\n" );
 	OSL_ENSURE( pParent, "No parent storage is provided!\n" );
-	OSL_ENSURE( m_nStorageType == embed::StorageFormats::OFOPXML || !m_xOrigRelInfoStream.is(), "The Relations info makes sence only for OFOPXML format!\n" );
+	OSL_ENSURE( m_nStorageType == embed::StorageFormats::OFOPXML || !m_xOrigRelInfoStream.is(), "The Relations info makes sense only for OFOPXML format!\n" );
 }
 
 //-----------------------------------------------
@@ -444,7 +444,7 @@ sal_Bool OWriteStream_Impl::IsEncrypted(
 		GetEncryptionKeyProperty_Impl( xPropSet ) >>= aKey;
 
 	// If the properties must be investigated the stream is either
 	// was never changed or was changed, the parent was commited
 	// and the stream was closed.
 	// That means that if it is intended to use common storage key
 	// it is already has no encryption but is marked to be stored
@@ -1634,7 +1634,7 @@ void OWriteStream_Impl::GetCopyOfLastCom
 
 	if ( m_bHasCachedEncryptionData )
 	{
 		// TODO: introduce last commited cashed password information and use it here
 		// that means "use common pass" also should be remembered on flash
 		uno::Sequence< beans::NamedValue > aKey = aEncryptionData.getAsConstNamedValueList();
 
@@ -1775,7 +1775,7 @@ void OWriteStream_Impl::CommitStreamRelI
 				}
 			}
 
 			// the original stream makes no sence after this step
 			m_xOrigRelInfoStream = m_xNewRelInfoStream;
 			m_aOrigRelInfo = m_aNewRelInfo;
 			m_bOrigRelInfoBroken = sal_False;
@@ -2443,7 +2443,7 @@ void OWriteStream::CloseOutput_Impl()
 
 	if ( !m_bInitOnDemand )
 	{
 		// after the stream is disposed it can be commited
 		// so transport correct size property
 		if ( !m_xSeekable.is() )
 			throw uno::RuntimeException();
@@ -3399,7 +3399,7 @@ void SAL_CALL OWriteStream::removeVetoab
 void OWriteStream::BroadcastTransaction( sal_Int8 nMessage )
 /*
 	1 - preCommit
-	2 - commited
+	2 - committed
 	3 - preRevert
 	4 - reverted
 */
@@ -3471,7 +3471,7 @@ void SAL_CALL OWriteStream::commit()
 
 		m_pImpl->Commit(); 
 
-		// when the storage is commited the parent is modified
+		// when the storage is committed the parent is modified
 		ModifyParentUnlockMutex_Impl( aGuard );
 	}
 	catch( io::IOException& aIOException )
@@ -444,7 +444,7 @@ sal_Bool OWriteStream_Impl::IsEncrypted(
 
 	// If the properties must be investigated the stream is either
-	// was never changed or was changed, the parent was commited
+	// was never changed or was changed, the parent was committed
 	// and the stream was closed.
 	// That means that if it is intended to use common storage key
@@ -1634,7 +1634,7 @@ void OWriteStream_Impl::GetCopyOfLastCom
 	if ( m_bHasCachedEncryptionData )
 	{
-		// TODO: introduce last commited cashed password information and use it here
+		// TODO: introduce last committed cashed password information and use it here
 		// that means "use common pass" also should be remembered on flash
 		uno::Sequence< beans::NamedValue > aKey = aEncryptionData.getAsConstNamedValueList();
@@ -1775,7 +1775,7 @@ void OWriteStream_Impl::CommitStreamRelI
 			}
 
-			// the original stream makes no sence after this step
+			// the original stream makes no sense after this step
 			m_xOrigRelInfoStream = m_xNewRelInfoStream;
 			m_aOrigRelInfo = m_aNewRelInfo;
@@ -2443,7 +2443,7 @@ void OWriteStream::CloseOutput_Impl()
 	if ( !m_bInitOnDemand )
 	{
-		// after the stream is disposed it can be commited
+		// after the stream is disposed it can be committed
 		// so transport correct size property
 		if ( !m_xSeekable.is() )

Modified: openoffice/trunk/main/package/source/xstor/xfactory.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/xstor/xfactory.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================
--- openoffice/trunk/main/package/source/xstor/xstorage.cxx (original)
+++ openoffice/trunk/main/package/source/xstor/xstorage.cxx Sun May 22 01:05:14 2016
@@ -131,7 +131,7 @@ void OStorage_Impl::completeStorageStrea
 		}
 		else if ( nStorageType == embed::StorageFormats::OFOPXML )
 		{
 			// TODO/LATER: in future it might make sence to provide the stream if there is one
 			uno::Reference< embed::XRelationshipAccess > xRelAccess( xDest, uno::UNO_QUERY_THROW );
 			xRelAccess->clearRelationships();
 			xRelAccess->insertRelationships( aRelInfo, sal_False );
@@ -458,7 +458,7 @@ void OStorage_Impl::RemoveReadOnlyWrap(
 //-----------------------------------------------
 void OStorage_Impl::OpenOwnPackage()
 {
-	OSL_ENSURE( m_bIsRoot, "Opening of the package has no sence!\n" );
+	OSL_ENSURE( m_bIsRoot, "Opening of the package has no sense!\n" );
 
 	::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
 
@@ -786,7 +786,7 @@ void OStorage_Impl::CopyToStorage( const
 		xRels->insertRelationships( GetAllRelationshipsIfAny(), sal_False );
 	}
 
-	// if possible the destination storage should be commited after successful copying
+	// if possible the destination storage should be committed after successful copying
 	uno::Reference< embed::XTransactedObject > xObjToCommit( xDest, uno::UNO_QUERY );
 	if ( xObjToCommit.is() )
 		xObjToCommit->commit();
@@ -1021,7 +1021,7 @@ void OStorage_Impl::CopyLastCommitTo( co
 {
 	::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
 
-	OSL_ENSURE( m_xPackageFolder.is(), "A commited storage is incomplete!\n" );
+	OSL_ENSURE( m_xPackageFolder.is(), "A committed storage is incomplete!\n" );
 	if ( !m_xPackageFolder.is() )
 		throw uno::RuntimeException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
 
@@ -1062,10 +1062,10 @@ void OStorage_Impl::Commit()
 
 	// in case of a new empty storage it is possible that the contents are still not read
 	// ( the storage of course has no contents, but the initialization is postponed till the first use,
 	//   thus if a new storage was created and commited immediately it must be initialized here )
 	ReadContents();
 
-	// if storage is commited it should have a valid Package representation
+	// if storage is committed it should have a valid Package representation
 	OSL_ENSURE( m_xPackageFolder.is(), "The package representation should exist!\n" );
 	if ( !m_xPackageFolder.is() )
 		throw embed::InvalidStorageException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
@@ -1076,7 +1076,7 @@ void OStorage_Impl::Commit()
 	uno::Reference< container::XNameContainer > xNewPackageFolder;
 
 	// here the storage will switch to the temporary package folder
-	// if the storage was already commited and the parent was not commited after that
+	// if the storage was already committed and the parent was not committed after that
 	// the switch should not be done since the package folder in use is a temporary one;
 	// it can be detected by m_bCommited flag ( root storage doesn't need temporary representation )
 	if ( !m_bCommited && !m_bIsRoot )
@@ -1144,7 +1144,7 @@ void OStorage_Impl::Commit()
 		if ( !(*pElementIter)->m_bIsInserted )
 		{
 			// for now stream is opened in direct mode that means that in case
 			// storage is commited all the streams from it are commited in current state.
 			// following two steps are separated to allow easily implement transacted mode
 			// for streams if we need it in future.
 			// Only hierarchical access uses transacted streams currently
@@ -1153,7 +1153,7 @@ void OStorage_Impl::Commit()
 				(*pElementIter)->m_pStream->Commit();
 
 			// if the storage was not open, there is no need to commit it ???
 			// the storage should be checked that it is commited
 			if ( (*pElementIter)->m_bIsStorage && (*pElementIter)->m_pStorage && (*pElementIter)->m_pStorage->m_bCommited )
 			{
 				// it's temporary PackageFolder should be inserted instead of current one
@@ -1479,7 +1479,7 @@ SotElement_Impl* OStorage_Impl::InsertRa
 	// the mode is not needed for storage stream internal implementation
 	SotElement_Impl* pNewElement = InsertElement( aName, sal_False );
 	pNewElement->m_pStream = new OWriteStream_Impl( this, xPackageSubStream, m_xPackage, m_xFactory, sal_True, m_nStorageType, sal_False );
 	// the stream is inserted and must be treated as a commited one
 	pNewElement->m_pStream->SetToBeCommited();
 
 	m_aChildrenList.push_back( pNewElement );
@@ -2141,7 +2141,7 @@ void OStorage::BroadcastModifiedIfNecess
 void OStorage::BroadcastTransaction( sal_Int8 nMessage )
 /*
 	1 - preCommit
-	2 - commited
+	2 - committed
 	3 - preRevert
 	4 - reverted
 */
@@ -2623,7 +2623,7 @@ uno::Reference< embed::XStorage > SAL_CA
 	  && !( nStorageMode & embed::ElementModes::WRITE ) )
 		throw io::IOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() ); // TODO: access denied
 
-	// it's allways possible to read written storage in this implementation
+	// it's always possible to read written storage in this implementation
 	nStorageMode |= embed::ElementModes::READ;
 
 	uno::Reference< embed::XStorage > xResult;
@@ -2937,7 +2937,7 @@ void SAL_CALL OStorage::copyStorageEleme
 	  && aStorName.equals( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "_rels" ) ) ) )
 		throw lang::IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >(), 1 ); // unacceptable storage name
 
-	// it's allways possible to read written storage in this implementation
+	// it's always possible to read written storage in this implementation
 	sal_Int32 nStorageMode = embed::ElementModes::READ;
 
 	try
@@ -4127,7 +4127,7 @@ void SAL_CALL OStorage::commit()
 
 		m_pImpl->Commit(); // the root storage initiates the storing to source
 
-		// when the storage is commited the parent is modified
+		// when the storage is committed the parent is modified
 		if ( m_pImpl->m_pParent && m_pImpl->m_pParent->m_pAntiImpl )
 			xParentModif = (util::XModifiable*)m_pImpl->m_pParent->m_pAntiImpl;
 	}
@@ -131,7 +131,7 @@ void OStorage_Impl::completeStorageStrea
 		else if ( nStorageType == embed::StorageFormats::OFOPXML )
 		{
-			// TODO/LATER: in future it might make sence to provide the stream if there is one
+			// TODO/LATER: in future it might make sense to provide the stream if there is one
 			uno::Reference< embed::XRelationshipAccess > xRelAccess( xDest, uno::UNO_QUERY_THROW );
 			xRelAccess->clearRelationships();
@@ -1062,10 +1062,10 @@ void OStorage_Impl::Commit()
 	// in case of a new empty storage it is possible that the contents are still not read
 	// ( the storage of course has no contents, but the initialization is postponed till the first use,
-	//   thus if a new storage was created and commited immediately it must be initialized here )
+	//   thus if a new storage was created and committed immediately it must be initialized here )
 	ReadContents();
 
@@ -1144,7 +1144,7 @@ void OStorage_Impl::Commit()
 		{
 			// for now stream is opened in direct mode that means that in case
-			// storage is commited all the streams from it are commited in current state.
+			// storage is committed all the streams from it are committed in current state.
 			// following two steps are separated to allow easily implement transacted mode
 			// for streams if we need it in future.
@@ -1153,7 +1153,7 @@ void OStorage_Impl::Commit()
 
 			// if the storage was not open, there is no need to commit it ???
-			// the storage should be checked that it is commited
+			// the storage should be checked that it is committed
 			if ( (*pElementIter)->m_bIsStorage && (*pElementIter)->m_pStorage && (*pElementIter)->m_pStorage->m_bCommited )
 			{
@@ -1479,7 +1479,7 @@ SotElement_Impl* OStorage_Impl::InsertRa
 	SotElement_Impl* pNewElement = InsertElement( aName, sal_False );
 	pNewElement->m_pStream = new OWriteStream_Impl( this, xPackageSubStream, m_xPackage, m_xFactory, sal_True, m_nStorageType, sal_False );
-	// the stream is inserted and must be treated as a commited one
+	// the stream is inserted and must be treated as a committed one
 	pNewElement->m_pStream->SetToBeCommited();
 

Modified: openoffice/trunk/main/package/source/zippackage/ZipPackage.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/package/source/zippackage/ZipPackage.cxx?rev=1745006&r1=1745005&r2=1745006&view=diff
==============================================================================